@@ -1006,19 +1006,29 @@ def tma_grid(
     }
     df_coor['scene_coor'] = df_coor.T.apply(lambda n: d_coor[n.grid_y] + str(int(n.grid_x + 1)).zfill(2))
 
-    # generate tick labels
-    li_grid_y = sorted(set(df_coor.grid_y))
-    ls_grid_y = [d_coor[i_grid_y] for i_grid_y in li_grid_y]
-    li_grid_x = [i_grid_x + 1 for i_grid_x in sorted(set(df_coor.grid_x))]
+    # get coordinates with collapsed cores
+    df_coor['core_collapse'] = False
+    df_count = df_coor.loc[:, ['scene_coor','core_collapse']].groupby('scene_coor').count()
+    df_coor.loc[
+        df_coor.scene_coor.isin(set(df_count.loc[df_count.core_collapse > 1, :].index)),
+        'core_collapse',
+    ] = True
 
     # write result to file
     s_pathfile_csv = f'{s_metadir}{s_slide}_ScenePositions_coor.csv'
     df_coor.to_csv(s_pathfile_csv)
     print('write to file:', s_pathfile_csv)
 
+    # generate tick labels
+    li_grid_y = sorted(set(df_coor.grid_y))
+    ls_grid_y = [d_coor[i_grid_y] for i_grid_y in li_grid_y]
+    li_grid_x = [i_grid_x + 1 for i_grid_x in sorted(set(df_coor.grid_x))]
+
     # qc plot result
     s_pathfile_png = f'{s_metadir}{s_slide}_ScenePositions_coor_{r_sampler}.png'
     s_title = f'{s_slide}_ScenePositions'
+    if any(df_coor.core_collapse):
+        s_title += f'\ncollapsed cores at coordinate {sorted(set(df_coor.loc[df_coor.core_collapse, "scene_coor"]))}'
     fig, ax = plt.subplots(nrows=2, ncols=1, figsize=(8,12))
     df_coor.plot(kind='scatter', x='grid_x', y='grid_y', c='maroon', s=128, grid=True, title=s_title, ax=ax[0])
     df_coor.plot(kind='scatter', x='scene_x', y='scene_y', c='orange', s=128, grid=True, ax=ax[1])
